@@ -44,7 +44,7 @@ class Request(object):
         """
         match = re.match(Request.VALID_REQUEST_REGEX, raw_data.decode("UTF-8"))
         if not match:
-            raise InvalidRequestException()
+            raise InvalidRequestException(raw_data)
 
         self = cls(
             match.group(1),
@@ -54,7 +54,7 @@ class Request(object):
         )
 
         if not len(self.b64_data) == self._content_length:
-            raise InvalidRequestException("Invalid Content_Length")
+            raise InvalidRequestException("Invalid Content_Length", raw_data)
         return self
 
     @staticmethod
