@@ -175,7 +175,7 @@ class KARPServer:
         self.logger.info(f"[+] New Connection from {_ip}")
         while not self.stopped:
             try:
-                requests = await reader.readuntil(b"\n")
+                requests = await reader.read()
             except (BrokenPipeError, ConnectionResetError):
                 break
             if not requests:
